@@ -3,8 +3,8 @@
 return [
     'Names' => [
         'TOP' => [
-            0 => 'T$',
-            1 => 'Tongan Paʻanga',
+            'T$',
+            'Tongan Paʻanga',
         ],
     ],
 ];
