@@ -14,6 +14,7 @@ namespace Symfony\Component\Workflow\Tests;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\EventDispatcher\EventDispatcher;
 use Symfony\Component\Workflow\Definition;
+use Symfony\Component\Workflow\Event\EnteredEvent;
 use Symfony\Component\Workflow\Event\Event;
 use Symfony\Component\Workflow\Event\GuardEvent;
 use Symfony\Component\Workflow\Event\TransitionEvent;
@@ -21,7 +22,6 @@ use Symfony\Component\Workflow\Exception\LogicException;
 use Symfony\Component\Workflow\Exception\NotEnabledTransitionException;
 use Symfony\Component\Workflow\Exception\UndefinedTransitionException;
 use Symfony\Component\Workflow\Marking;
-use Symfony\Component\Workflow\MarkingStore\MarkingStoreInterface;
 use Symfony\Component\Workflow\MarkingStore\MethodMarkingStore;
 use Symfony\Component\Workflow\Transition;
 use Symfony\Component\Workflow\TransitionBlocker;
@@ -32,16 +32,6 @@ class WorkflowTest extends TestCase
 {
     use WorkflowBuilderTrait;
 
-    public function testGetMarkingWithInvalidStoreReturn()
-    {
-        $this->expectException(LogicException::class);
-        $this->expectExceptionMessage('The value returned by the MarkingStore is not an instance of "Symfony\Component\Workflow\Marking" for workflow "unnamed".');
-        $subject = new Subject();
-        $workflow = new Workflow(new Definition([], []), $this->createMock(MarkingStoreInterface::class));
-
-        $workflow->getMarking($subject);
-    }
-
     public function testGetMarkingWithEmptyDefinition()
     {
         $this->expectException(LogicException::class);
@@ -438,14 +428,16 @@ class WorkflowTest extends TestCase
         $this->assertSame($eventNameExpected, $eventDispatcher->dispatchedEvents);
     }
 
-    public static function provideApplyWithEventDispatcherForAnnounceTests()
+    public static function provideApplyWithEventDispatcherForAnnounceTests(): \Generator
     {
         yield [false, [Workflow::DISABLE_ANNOUNCE_EVENT => true]];
         yield [true, [Workflow::DISABLE_ANNOUNCE_EVENT => false]];
         yield [true, []];
     }
 
-    /** @dataProvider provideApplyWithEventDispatcherForAnnounceTests */
+    /**
+     * @dataProvider provideApplyWithEventDispatcherForAnnounceTests
+     */
     public function testApplyWithEventDispatcherForAnnounce(bool $fired, array $context)
     {
         $definition = $this->createComplexWorkflowDefinition();
@@ -694,6 +686,44 @@ class WorkflowTest extends TestCase
         $workflow->apply($subject, 't1');
     }
 
+    public function testEventWhenAlreadyInThisPlace()
+    {
+        // ┌──────┐     ┌──────────────────────┐     ┌───┐     ┌─────────────┐     ┌───┐
+        // │ init │ ──▶ │ from_init_to_a_and_b │ ──▶ │ B │ ──▶ │ from_b_to_c │ ──▶ │ C │
+        // └──────┘     └──────────────────────┘     └───┘     └─────────────┘     └───┘
+        //                         │
+        //                         │
+        //                         ▼
+        //                     ┌───────────────────────────────┐
+        //                     │               A               │
+        //                     └───────────────────────────────┘
+        $definition = new Definition(
+            ['init', 'A', 'B', 'C'],
+            [
+                new Transition('from_init_to_a_and_b', 'init', ['A', 'B']),
+                new Transition('from_b_to_c', 'B', 'C'),
+            ],
+        );
+
+        $subject = new Subject();
+        $dispatcher = new EventDispatcher();
+        $name = 'workflow_name';
+        $workflow = new Workflow($definition, new MethodMarkingStore(), $dispatcher, $name);
+
+        $calls = [];
+        $listener = function (Event $event) use (&$calls) {
+            $calls[] = $event;
+        };
+        $dispatcher->addListener("workflow.$name.entered.A", $listener);
+
+        $workflow->apply($subject, 'from_init_to_a_and_b');
+        $workflow->apply($subject, 'from_b_to_c');
+
+        $this->assertCount(1, $calls);
+        $this->assertInstanceOf(EnteredEvent::class, $calls[0]);
+        $this->assertSame('from_init_to_a_and_b', $calls[0]->getTransition()->getName());
+    }
+
     public function testMarkingStateOnApplyWithEventDispatcher()
     {
         $definition = new Definition(range('a', 'f'), [new Transition('t', range('a', 'c'), range('d', 'f'))]);
@@ -789,9 +819,9 @@ class WorkflowTest extends TestCase
 
 class EventDispatcherMock implements \Symfony\Contracts\EventDispatcher\EventDispatcherInterface
 {
-    public $dispatchedEvents = [];
+    public array $dispatchedEvents = [];
 
-    public function dispatch($event, string $eventName = null): object
+    public function dispatch($event, ?string $eventName = null): object
     {
         $this->dispatchedEvents[] = $eventName;
 
